{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/gtf_file"
                },
                {
                    "type": "string",
                    "id": "#main/output_prefix"
                },
                {
                    "type": "string",
                    "id": "#main/splice_graph_type"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/tx_features_files"
                }
            ],
            "steps": [
                {
                    "run": "#generate_splice_graph_features.cwl",
                    "in": [
                        {
                            "source": "#main/output_prefix",
                            "id": "#main/generate_splice_graph_features/output_prefix"
                        },
                        {
                            "source": "#main/splice_graph_type",
                            "id": "#main/generate_splice_graph_features/splice_graph_type"
                        },
                        {
                            "source": "#main/generate_transcript_db/transcript_db_file",
                            "id": "#main/generate_splice_graph_features/transcript_db"
                        },
                        {
                            "source": "#main/tx_features_files",
                            "id": "#main/generate_splice_graph_features/txfeatures_files"
                        }
                    ],
                    "out": [
                        "#main/generate_splice_graph_features/annotated_splice_graph_file"
                    ],
                    "id": "#main/generate_splice_graph_features"
                },
                {
                    "run": "#find_splice_graph_variants.cwl",
                    "in": [
                        {
                            "source": "#main/output_prefix",
                            "id": "#main/generate_splice_graph_variants/output_prefix"
                        },
                        {
                            "source": "#main/generate_splice_graph_features/annotated_splice_graph_file",
                            "id": "#main/generate_splice_graph_variants/splice_graph"
                        }
                    ],
                    "out": [
                        "#main/generate_splice_graph_variants/splice_graph_variants_file"
                    ],
                    "id": "#main/generate_splice_graph_variants"
                },
                {
                    "run": "#generate_transcript_db.cwl",
                    "in": [
                        {
                            "source": "#main/gtf_file",
                            "id": "#main/generate_transcript_db/gtf_file"
                        },
                        {
                            "valueFrom": "$(inputs.gtf_file.basename).transcript_db.RData",
                            "id": "#main/generate_transcript_db/out_file"
                        }
                    ],
                    "out": [
                        "#main/generate_transcript_db/transcript_db_file"
                    ],
                    "id": "#main/generate_transcript_db"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/generate_splice_graph_features/annotated_splice_graph_file",
                    "id": "#main/splice_graph_features_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/generate_splice_graph_variants/splice_graph_variants_file",
                    "id": "#main/splice_graph_variants_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "Rscript",
                "--vanilla",
                "/projects/rdocking_prj/software/sgseq_cwl/r/find_splice_graph_variants.r"
            ],
            "inputs": [
                {
                    "id": "#find_splice_graph_variants.cwl/splice_graph",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#find_splice_graph_variants.cwl/output_prefix",
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#find_splice_graph_variants.cwl/splice_graph_variants_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix).sg_variants.RData"
                    }
                }
            ],
            "arguments": [
                "--cpus",
                "$(runtime.cores)"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 42000,
                    "coresMin": 1,
                    "tmpdirMin": 40000
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "id": "#find_splice_graph_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "Rscript",
                "--vanilla",
                "/projects/rdocking_prj/software/sgseq_cwl/r/generate_splice_graph_features.r"
            ],
            "inputs": [
                {
                    "id": "#generate_splice_graph_features.cwl/transcript_db",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#generate_splice_graph_features.cwl/output_prefix",
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    }
                },
                {
                    "id": "#generate_splice_graph_features.cwl/splice_graph_type",
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    }
                },
                {
                    "id": "#generate_splice_graph_features.cwl/txfeatures_files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--txfeatures_files"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#generate_splice_graph_features.cwl/annotated_splice_graph_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix).sg_features.RData"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 42000,
                    "tmpdirMin": 40000
                }
            ],
            "id": "#generate_splice_graph_features.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "Rscript",
                "--vanilla",
                "/projects/rdocking_prj/software/sgseq_cwl/r/generate_transcript_db.r"
            ],
            "inputs": [
                {
                    "id": "#generate_transcript_db.cwl/gtf_file",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#generate_transcript_db.cwl/out_file",
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#generate_transcript_db.cwl/transcript_db_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.out_file)"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 42000,
                    "tmpdirMin": 40000
                }
            ],
            "id": "#generate_transcript_db.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
